@@ -1,5 +1,6 @@
 import datetime
 from enum import Enum
+from functools import total_ordering
 from typing import Dict, List, Union
 
 
@@ -78,17 +79,18 @@ class KonanDockerImage():
         self.exposed_port = exposed_port
 
 
-class KonanDeploymentCreationRequest():
-    """Information required to issue a create a new Konan Deployment.
+class KonanModelCreationRequest():
+    """Information required to create a new Konan Model.
     """
     def __init__(
-        self, name: str,
+        self,
+        name: str,
         docker_credentials: KonanDockerCredentials,
-        docker_image: KonanDockerImage
+        docker_image: KonanDockerImage,
     ) -> None:
-        """ Initialize a new KonanDeploymentCreationRequest.
+        """Initialize a new KonanModelCreationRequest.
 
-        :param name: Name of the new Konan Deployment.
+        :param name: Name of the new Konan Mode.
         :type name: str
         :param docker_credentials: Credentials of the Docker Container Registry to use
         :type docker_credentials: KonanDockerCredentials
@@ -100,6 +102,25 @@ class KonanDeploymentCreationRequest():
         self.docker_image = docker_image
 
 
+class KonanDeploymentCreationRequest():
+    """Information required to issue a create a new Konan Deployment.
+    """
+    def __init__(
+        self,
+        name: str,
+        model_creation_request: KonanModelCreationRequest,
+    ) -> None:
+        """ Initialize a new KonanDeploymentCreationRequest.
+
+        :param name: Name of the new Konan Deployment.
+        :type name: str
+        :param model_creation_request: Information required to create a new Konan Model.
+        :type model_creation_request: KonanModelCreationRequest
+        """
+        self.name = name
+        self.model_creation_request = model_creation_request
+
+
 class KonanDeploymentErrorType(Enum):
     """Different error types possibly returned by the Konan API when attempting to create a new Konan Deployment.
 
@@ -126,12 +147,89 @@ class KonanDeploymentError():
         self.message = message
 
 
+class KonanModelState(Enum):
+    """Different states a KonanModel can be in
+
+    :param Enum: [description]
+    :type Enum: [type]
+    """
+    Live = 'live'  #: Model Live State
+    Challenger = 'challenger'  #: Model Challenger State
+    Disabled = 'disabled'  #: Model Disabled State
+    Other = "other"  #: Model Other State
+
+
+class KonanLiveModelSwitchState():
+    """Konan Live Model Switch State
+    """
+    def __init__(
+        self,
+        switch_to: KonanModelState,
+        new_live_model_uuid: str,
+    ) -> None:
+        """Initialize a new KonanLiveModelSwitchState
+
+        :param switch_to: state of model to switch to
+        :type switch_to: KonanModelState
+        :param new_live_model_uuid: UUID of the model to promote to live
+        :type new_live_model_uuid: str
+        """
+        self.switch_to = switch_to
+        self.new_live_model_uuid = new_live_model_uuid
+
+
+@total_ordering
+class KonanModel():
+    """Konan Model
+    """
+    def __init__(
+        self,
+        uuid: str,
+        name: str,
+        created_at: datetime.datetime,
+        state: KonanModelState,
+    ) -> None:
+        """Initialize a new KonanModel
+
+        :param uuid: UUID of the Konan Mode
+        :type uuid: str
+        :param name: Name of the Konan Mode
+        :type name: str
+        :param created_at: Konan Model creation date and time
+        :type created_at: datetime.datetime
+        :param state: State of the Konan Model
+        :type state: KonanModelState
+        """
+        self.uuid = uuid
+        self.name = name
+        self.created_at = created_at
+        self.state = state
+
+    def __eq__(self, __o: object) -> bool:
+        if not isinstance(__o, KonanModel):
+            return False
+        __other_model: KonanModel = __o
+        return (
+            self.uuid == __other_model.uuid
+            and self.name == __other_model.name
+            and self.created_at == __other_model.created_at
+            and self.state == __other_model.state
+        )
+
+    def __lt__(self, __o: object) -> bool:
+        assert isinstance(__o, KonanModel)
+        __other_model: KonanModel = __o
+        return self.uuid < __other_model.uuid
+
+
 class KonanDeployment():
     """Konan Deployment.
     """
     def __init__(
         self,
-        uuid: str, name: str, created_at: datetime.datetime
+        uuid: str,
+        name: str,
+        created_at: datetime.datetime,
     ) -> None:
         """ Initialize a new KonanDeployment.
 
@@ -153,7 +251,9 @@ class KonanDeploymentCreationResponse():
     def __init__(
         self,
         deployment: KonanDeployment,
-        errors: List[KonanDeploymentError], container_logs: str
+        live_model: KonanModel,
+        errors: List[KonanDeploymentError],
+        container_logs: str,
     ) -> None:
         """ Initialize a new KonanDeploymentCreationResponse.
 
@@ -161,10 +261,11 @@ class KonanDeploymentCreationResponse():
         :type deployment: KonanDeployment
         :param errors: Errors encountered when attempting to create the new Konan Deployment
         :type errors: List[KonanDeploymentError]
-        :param container_logs: Container logs genered when creating the new Konan Deployment
+        :param container_logs: Container logs generated when creating the new Konan Deployment
         :type container_logs: str
         """
         self.deployment = deployment
+        self.live_model = live_model
         self.errors = errors,
         self.container_logs = container_logs
 
